@@ -25,7 +25,6 @@ from test import results  # noqa E402
 
 # temporary issues, etc.
 BROKEN = {
-    "photobucket",
 }
 
 CONFIG = {
@@ -54,6 +53,7 @@ AUTH_CONFIG = (
     "cookies",
     "api-key",
     "client-id",
+    "access-token",
     "refresh-token",
 )
 
@@ -88,6 +88,19 @@ class TestExtractorResults(unittest.TestCase):
         result.pop("#comment", None)
         only_matching = (len(result) <= 3)
 
+        auth = result.get("#auth")
+        if auth is None:
+            auth = (result["#category"][1] in AUTH)
+        elif not auth:
+            for key in AUTH_CONFIG:
+                config.set((), key, None)
+
+        if auth:
+            extr = result["#class"].from_url(result["#url"])
+            if not any(extr.config(key) for key in AUTH_CONFIG):
+                self._skipped.append((result["#url"], "no auth"))
+                only_matching = True
+
         if only_matching:
             content = False
         else:
@@ -95,21 +108,6 @@ class TestExtractorResults(unittest.TestCase):
                 for key, value in result["#options"].items():
                     key = key.split(".")
                     config.set(key[:-1], key[-1], value)
-
-            auth = result.get("#auth")
-            if auth is None:
-                auth = (result["#category"][1] in AUTH)
-            elif not auth:
-                for key in AUTH_CONFIG:
-                    config.set((), key, None)
-
-            if auth:
-                extr = result["#class"].from_url(result["#url"])
-                if not any(extr.config(key) for key in AUTH_CONFIG):
-                    msg = "no auth"
-                    self._skipped.append((result["#url"], msg))
-                    self.skipTest(msg)
-
             if "#range" in result:
                 config.set((), "image-range"  , result["#range"])
                 config.set((), "chapter-range", result["#range"])
@@ -214,44 +212,46 @@ class TestExtractorResults(unittest.TestCase):
             for kwdict in tjob.kwdict_list:
                 self._test_kwdict(kwdict, metadata)
 
-    def _test_kwdict(self, kwdict, tests):
+    def _test_kwdict(self, kwdict, tests, parent=None):
         for key, test in tests.items():
             if key.startswith("?"):
                 key = key[1:]
                 if key not in kwdict:
                     continue
-            self.assertIn(key, kwdict, msg=key)
+            path = "{}.{}".format(parent, key) if parent else key
+            self.assertIn(key, kwdict, msg=path)
             value = kwdict[key]
 
             if isinstance(test, dict):
-                self._test_kwdict(value, test)
+                self._test_kwdict(value, test, path)
             elif isinstance(test, type):
-                self.assertIsInstance(value, test, msg=key)
+                self.assertIsInstance(value, test, msg=path)
             elif isinstance(test, range):
-                self.assertRange(value, test, msg=key)
+                self.assertRange(value, test, msg=path)
             elif isinstance(test, list):
                 subtest = False
                 for idx, item in enumerate(test):
                     if isinstance(item, dict):
                         subtest = True
-                        self._test_kwdict(value[idx], item)
+                        subpath = "{}[{}]".format(path, idx)
+                        self._test_kwdict(value[idx], item, subpath)
                 if not subtest:
-                    self.assertEqual(test, value, msg=key)
+                    self.assertEqual(test, value, msg=path)
             elif isinstance(test, str):
                 if test.startswith("re:"):
-                    self.assertRegex(value, test[3:], msg=key)
+                    self.assertRegex(value, test[3:], msg=path)
                 elif test.startswith("dt:"):
-                    self.assertIsInstance(value, datetime.datetime, msg=key)
-                    self.assertEqual(test[3:], str(value), msg=key)
+                    self.assertIsInstance(value, datetime.datetime, msg=path)
+                    self.assertEqual(test[3:], str(value), msg=path)
                 elif test.startswith("type:"):
-                    self.assertEqual(test[5:], type(value).__name__, msg=key)
+                    self.assertEqual(test[5:], type(value).__name__, msg=path)
                 elif test.startswith("len:"):
-                    self.assertIsInstance(value, (list, tuple), msg=key)
-                    self.assertEqual(int(test[4:]), len(value), msg=key)
+                    self.assertIsInstance(value, (list, tuple), msg=path)
+                    self.assertEqual(int(test[4:]), len(value), msg=path)
                 else:
-                    self.assertEqual(test, value, msg=key)
+                    self.assertEqual(test, value, msg=path)
             else:
-                self.assertEqual(test, value, msg=key)
+                self.assertEqual(test, value, msg=path)
 
 
 class ResultJob(job.DownloadJob):
@@ -440,7 +440,15 @@ def generate_tests():
             tests = results.category(category)
 
         if subcategory:
-            tests = [t for t in tests if t["#category"][-1] == subcategory]
+            if subcategory.startswith("+"):
+                url = subcategory[1:]
+                tests = [t for t in tests if url in t["#url"]]
+            elif subcategory.startswith("~"):
+                com = subcategory[1:]
+                tests = [t for t in tests
+                         if "#comment" in t and com in t["#comment"].lower()]
+            else:
+                tests = [t for t in tests if t["#category"][-1] == subcategory]
     else:
         tests = results.all()
 
